@@ -133,17 +133,18 @@ def define_additional_meta(nlamps=20):
                        'dithpos': dict(dtype=str, comment='Dither position'),
                        'dithoff': dict(dtype=float, comment='Dither offset'),
                        'filter1': dict(dtype=str, comment='First filter in optical path'),
+                       'frameno': dict(dtype=str, comment='Frame number provided by instrument software'),
                        'hatch': dict(dtype=str, comment='Position of instrument hatch'),
-                       'humidity': dict(dtype=float, comment='Relative humidity (0 to 1) at obstime'),
+                       'humidity': dict(dtype=float, comment='Relative humidity (0 to 1) at observation time'),
                        'idname': dict(dtype=str, comment='Instrument supplied frametype (e.g. bias)'),
                        'mode': dict(dtype=str, comment='Observing mode'),
                        'object': dict(dtype=str, comment='Alternative object name (cf. target)'),
                        'obstime': dict(dtype=str, comment='Observation time'),
                        'oscansec': dict(dtype=str, comment='Overscan section (windowing)'),
-                       'pressure': dict(dtype=float, comment='Pressure at obstime'),
+                       'pressure': dict(dtype=float, comment='Pressure (units.bar) at observation time'),
                        'seq_expno': dict(dtype=int, comment='Number of exposure in observing sequence'),
                        'slitwid': dict(dtype=float, comment='Slit width, sometimes distinct from decker'),
-                       'temperature': dict(dtype=float, comment='Temperature at obstime'),
+                       'temperature': dict(dtype=float, comment='Temperature (units.K) at observation time'),
                        'utc': dict(dtype=str, comment='UTC of observation')}
 
     for kk in range(nlamps):
