@@ -10,14 +10,14 @@ from IPython import embed
 import numpy as np
 
 import pytest
-import yaml
 from configobj import ConfigObj
 
 from pypeit.pypmsgs import PypeItError
 from pypeit.metadata import PypeItMetaData
 from pypeit.par import PypeItPar
 from pypeit.par.util import parse_pypeit_file
-from pypeit.scripts import setup, chk_for_calibs
+from pypeit.scripts.setup import Setup
+from pypeit.scripts.chk_for_calibs import ChkForCalibs
 from pypeit.spectrographs.util import load_spectrograph
 from pypeit.tests.tstutils import dev_suite_required
 from pypeit import pypeit
@@ -42,9 +42,9 @@ def test_run_setup():
         os.remove(sfile)
     #
     droot = data_path('b')
-    pargs = setup.parse_args(['-r', droot, '-s', 'shane_kast_blue', '-c=all',
+    pargs = Setup.parse_args(['-r', droot, '-s', 'shane_kast_blue', '-c=all',
                               '--extension=fits.gz', '--output_path={:s}'.format(data_path(''))])
-    setup.main(pargs)
+    Setup.main(pargs)
 
     #setup_file = glob.glob(data_path('setup_files/shane_kast_blue*.setups'))[0]
     ## Load
@@ -54,10 +54,10 @@ def test_run_setup():
     #assert '01' in setup_dict['A'].keys()
     #assert setup_dict['A']['--']['disperser']['name'] == '600/4310'
     # Failures
-    pargs2 = setup.parse_args(['-r', droot, '-s', 'shane_kast_blu', '-c=all',
+    pargs2 = Setup.parse_args(['-r', droot, '-s', 'shane_kast_blu', '-c=all',
                                '--extension=fits.gz', '--output_path={:s}'.format(data_path(''))])
     with pytest.raises(ValueError):
-        setup.main(pargs2)
+        Setup.main(pargs2)
     
     # Cleanup
     shutil.rmtree(data_path('setup_files'))
@@ -82,8 +82,8 @@ def test_setup_made_pypeit_file():
 def test_setup_keck_lris_red():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/keck_lris_red/multi_400_8500_d560')
     droot += '/'
-    pargs = setup.parse_args(['-r', droot, '-s', 'keck_lris_red'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'keck_lris_red'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -103,8 +103,8 @@ def test_setup_keck_lris_red():
 def test_setup_keck_lris_red_orig():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/keck_lris_red_orig/long_300_5000')
     droot += '/'
-    pargs = setup.parse_args(['-r', droot, '-s', 'keck_lris_red_orig'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'keck_lris_red_orig'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -124,8 +124,8 @@ def test_setup_keck_lris_red_orig():
 def test_setup_keck_lris_blue():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/keck_lris_blue/multi_600_4000_d560')
     droot += '/'
-    pargs = setup.parse_args(['-r', droot, '-s', 'keck_lris_blue'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'keck_lris_blue'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -145,8 +145,8 @@ def test_setup_keck_lris_blue():
 def test_setup_keck_lris_blue_orig():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/keck_lris_blue_orig/long_600_4000_d500')
     droot += '/'
-    pargs = setup.parse_args(['-r', droot, '-s', 'keck_lris_blue_orig'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'keck_lris_blue_orig'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -166,8 +166,8 @@ def test_setup_keck_lris_blue_orig():
 def test_setup_shane_kast_blue():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/shane_kast_blue/600_4310_d55')
     droot += '/'
-    pargs = setup.parse_args(['-r', droot, '-s', 'shane_kast_blue'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'shane_kast_blue'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -187,8 +187,8 @@ def test_setup_shane_kast_blue():
 def test_setup_shane_kast_red():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/shane_kast_red/600_7500_d55_ret')
     droot += '/'
-    pargs = setup.parse_args(['-r', droot, '-s', 'shane_kast_red'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'shane_kast_red'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -210,8 +210,8 @@ def test_setup_keck_deimos():
 
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/keck_deimos/830G_M_8600')
     droot += '/'
-    pargs = setup.parse_args(['-r', droot, '-s', 'keck_deimos'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'keck_deimos'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -318,8 +318,8 @@ def test_setup_keck_deimos_multiconfig_clean():
 def test_setup_keck_nires():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/keck_nires/NIRES/')
     droot += '/'
-    pargs = setup.parse_args(['-r', droot, '-s', 'keck_nires'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'keck_nires'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -339,8 +339,8 @@ def test_setup_keck_nires():
 def test_setup_keck_nirspec():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/keck_nirspec/LOW_NIRSPEC-1')
     droot += '/'
-    pargs = setup.parse_args(['-r', droot, '-s', 'keck_nirspec_low'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'keck_nirspec_low'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -360,8 +360,8 @@ def test_setup_keck_nirspec():
 def test_setup_magellan_mage():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/magellan_mage/1x1')
     droot += '/'
-    pargs = setup.parse_args(['-r', droot, '-s', 'magellan_mage'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'magellan_mage'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -381,8 +381,8 @@ def test_setup_magellan_mage():
 def test_setup_wht_isis_blue():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/wht_isis_blue/long_R300B_d5300')
     droot += '/'
-    pargs = setup.parse_args(['-r', droot, '-s', 'wht_isis_blue', '--extension', '.fit'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'wht_isis_blue', '--extension', '.fit'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -402,8 +402,8 @@ def test_setup_wht_isis_blue():
 def test_setup_vlt_xshooter_uvb():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/vlt_xshooter/UVB_1x1')
     droot += '/XSHO'
-    pargs = setup.parse_args(['-r', droot, '-s', 'vlt_xshooter_uvb'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'vlt_xshooter_uvb'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -423,8 +423,8 @@ def test_setup_vlt_xshooter_uvb():
 def test_setup_vlt_xshooter_vis():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/vlt_xshooter/VIS_1x1')
     droot += '/XSHO'
-    pargs = setup.parse_args(['-r', droot, '-s', 'vlt_xshooter_vis'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'vlt_xshooter_vis'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -444,8 +444,8 @@ def test_setup_vlt_xshooter_vis():
 def test_setup_vlt_xshooter_nir():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/vlt_xshooter/NIR')
     droot += '/XSHO'
-    pargs = setup.parse_args(['-r', droot, '-s', 'vlt_xshooter_nir'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'vlt_xshooter_nir'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -465,8 +465,8 @@ def test_setup_vlt_xshooter_nir():
 def test_setup_gemini_gnirs():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/gemini_gnirs/32_SB_SXD/')
     droot += '/cN'
-    pargs = setup.parse_args(['-r', droot, '-s', 'gemini_gnirs'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'gemini_gnirs'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -486,8 +486,8 @@ def test_setup_gemini_gnirs():
 def test_setup_not_alfosc():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/not_alfosc/grism4')
     droot += '/ALD'
-    pargs = setup.parse_args(['-r', droot, '-s', 'not_alfosc'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'not_alfosc'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -500,8 +500,8 @@ def test_setup_not_alfosc():
         'Did not find all setup file extensions: {0}'.format(expected)
 
     # Build a PypeIt file
-    pargs = setup.parse_args(['-r', droot, '-s', 'not_alfosc', '-c', 'A', '-d', data_path('')])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'not_alfosc', '-c', 'A', '-d', data_path('')])
+    Setup.main(pargs)
     pypeit_file = data_path('not_alfosc_A/not_alfosc_A.pypeit')
     # TODO: Why is this using pypeit.PypeIt and not pypeitsetup.PypeItSetup?
     pypeIt = pypeit.PypeIt(pypeit_file, calib_only=True)
@@ -514,8 +514,8 @@ def test_setup_not_alfosc():
 def test_setup_vlt_fors2():
     droot = os.path.join(os.environ['PYPEIT_DEV'], 'RAW_DATA/vlt_fors2/300I/')
     droot += '/FORS2'
-    pargs = setup.parse_args(['-r', droot, '-s', 'vlt_fors2'])
-    setup.main(pargs)
+    pargs = Setup.parse_args(['-r', droot, '-s', 'vlt_fors2'])
+    Setup.main(pargs)
 
     cwd = os.getcwd()
     setup_dir = os.path.join(cwd, 'setup_files')
@@ -531,8 +531,8 @@ def test_setup_vlt_fors2():
     shutil.rmtree(setup_dir)
 
     # Now chk calib
-    pargs = chk_for_calibs.parse_args([droot, '-s', 'vlt_fors2'])
-    answers, ps = chk_for_calibs.main(pargs)
+    pargs = ChkForCalibs.parse_args([droot, '-s', 'vlt_fors2'])
+    answers, ps = ChkForCalibs.main(pargs)
     assert answers['pass'][0], 'A must pass!'
 
 # TODO: Add other instruments!
